'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var view = require('@codemirror/view');
var highlight = require('@codemirror/highlight');

// Using https://github.com/one-dark/vscode-one-dark-theme/ as reference for the colors
const chalky = "#e5c07b", coral = "#e06c75", cyan = "#56b6c2", invalid = "#ffffff", ivory = "#abb2bf", stone = "#7d8799", // Brightened compared to original to increase contrast
malibu = "#61afef", sage = "#98c379", whiskey = "#d19a66", violet = "#c678dd", darkBackground = "#21252b", highlightBackground = "#2c313a", background = "#282c34", selection = "#3E4451", cursor = "#528bff";
/// The editor theme styles for One Dark.
const oneDarkTheme = view.EditorView.theme({
    $: {
        color: ivory,
        backgroundColor: background,
        "& ::selection": { backgroundColor: selection },
        caretColor: cursor
    },
    "$$focused $cursor": { borderLeftColor: cursor },
    "$$focused $selectionBackground, $selectionBackground": { backgroundColor: selection },
    $panels: { backgroundColor: darkBackground, color: ivory },
    "$panels.top": { borderBottom: "2px solid black" },
    "$panels.bottom": { borderTop: "2px solid black" },
    $searchMatch: {
        backgroundColor: "#72a1ff59",
        outline: "1px solid #457dff"
    },
    "$searchMatch.selected": {
        backgroundColor: "#6199ff2f"
    },
    $activeLine: { backgroundColor: highlightBackground },
    $selectionMatch: { backgroundColor: "#aafe661a" },
    "$matchingBracket, $nonmatchingBracket": {
        backgroundColor: "#bad0f847",
        outline: "1px solid #515a6b"
    },
    $gutters: {
        backgroundColor: background,
        color: stone,
        border: "none"
    },
    "$gutterElement.lineNumber": { color: "inherit" },
    $foldPlaceholder: {
        backgroundColor: "transparent",
        border: "none",
        color: "#ddd"
    },
    $tooltip: {
        border: "1px solid #181a1f",
        backgroundColor: darkBackground
    },
    "$tooltip.autocomplete": {
        "& > ul > li[aria-selected]": {
            backgroundColor: highlightBackground,
            color: ivory
        }
    }
}, { dark: true });
/// The highlighting style for code in the One Dark theme.
const oneDarkHighlightStyle = highlight.HighlightStyle.define({ tag: highlight.tags.keyword,
    color: violet }, { tag: [highlight.tags.name, highlight.tags.deleted, highlight.tags.character, highlight.tags.propertyName, highlight.tags.macroName],
    color: coral }, { tag: [highlight.tags.function(highlight.tags.variableName), highlight.tags.labelName],
    color: malibu }, { tag: [highlight.tags.color, highlight.tags.constant(highlight.tags.name), highlight.tags.standard(highlight.tags.name)],
    color: whiskey }, { tag: [highlight.tags.definition(highlight.tags.name), highlight.tags.separator],
    color: ivory }, { tag: [highlight.tags.typeName, highlight.tags.className, highlight.tags.number, highlight.tags.changed, highlight.tags.annotation, highlight.tags.modifier, highlight.tags.self, highlight.tags.namespace],
    color: chalky }, { tag: [highlight.tags.operator, highlight.tags.operatorKeyword, highlight.tags.url, highlight.tags.escape, highlight.tags.regexp, highlight.tags.link, highlight.tags.special(highlight.tags.string)],
    color: cyan }, { tag: [highlight.tags.meta, highlight.tags.comment],
    color: stone }, { tag: highlight.tags.strong,
    fontWeight: "bold" }, { tag: highlight.tags.emphasis,
    fontStyle: "italic" }, { tag: highlight.tags.link,
    color: stone,
    textDecoration: "underline" }, { tag: highlight.tags.heading,
    fontWeight: "bold",
    color: coral }, { tag: [highlight.tags.atom, highlight.tags.bool, highlight.tags.special(highlight.tags.variableName)],
    color: whiskey }, { tag: [highlight.tags.processingInstruction, highlight.tags.string, highlight.tags.inserted],
    color: sage }, { tag: highlight.tags.invalid,
    color: invalid });
/// Extension to enable the One Dark theme (both the editor theme and
/// the highlight style).
const oneDark = [oneDarkTheme, oneDarkHighlightStyle];

exports.oneDark = oneDark;
exports.oneDarkHighlightStyle = oneDarkHighlightStyle;
exports.oneDarkTheme = oneDarkTheme;
