import { EditorView } from '@codemirror/view';
import { HighlightStyle, tags } from '@codemirror/highlight';

// Using https://github.com/one-dark/vscode-one-dark-theme/ as reference for the colors
const chalky = "#e5c07b", coral = "#e06c75", cyan = "#56b6c2", invalid = "#ffffff", ivory = "#abb2bf", stone = "#7d8799", // Brightened compared to original to increase contrast
malibu = "#61afef", sage = "#98c379", whiskey = "#d19a66", violet = "#c678dd", darkBackground = "#21252b", highlightBackground = "#2c313a", background = "#282c34", selection = "#3E4451", cursor = "#528bff";
/// The editor theme styles for One Dark.
const oneDarkTheme = EditorView.theme({
    $: {
        color: ivory,
        backgroundColor: background,
        "& ::selection": { backgroundColor: selection },
        caretColor: cursor
    },
    "$$focused $cursor": { borderLeftColor: cursor },
    "$$focused $selectionBackground, $selectionBackground": { backgroundColor: selection },
    $panels: { backgroundColor: darkBackground, color: ivory },
    "$panels.top": { borderBottom: "2px solid black" },
    "$panels.bottom": { borderTop: "2px solid black" },
    $searchMatch: {
        backgroundColor: "#72a1ff59",
        outline: "1px solid #457dff"
    },
    "$searchMatch.selected": {
        backgroundColor: "#6199ff2f"
    },
    $activeLine: { backgroundColor: highlightBackground },
    $selectionMatch: { backgroundColor: "#aafe661a" },
    "$matchingBracket, $nonmatchingBracket": {
        backgroundColor: "#bad0f847",
        outline: "1px solid #515a6b"
    },
    $gutters: {
        backgroundColor: background,
        color: stone,
        border: "none"
    },
    "$gutterElement.lineNumber": { color: "inherit" },
    $foldPlaceholder: {
        backgroundColor: "transparent",
        border: "none",
        color: "#ddd"
    },
    $tooltip: {
        border: "1px solid #181a1f",
        backgroundColor: darkBackground
    },
    "$tooltip.autocomplete": {
        "& > ul > li[aria-selected]": {
            backgroundColor: highlightBackground,
            color: ivory
        }
    }
}, { dark: true });
/// The highlighting style for code in the One Dark theme.
const oneDarkHighlightStyle = HighlightStyle.define({ tag: tags.keyword,
    color: violet }, { tag: [tags.name, tags.deleted, tags.character, tags.propertyName, tags.macroName],
    color: coral }, { tag: [tags.function(tags.variableName), tags.labelName],
    color: malibu }, { tag: [tags.color, tags.constant(tags.name), tags.standard(tags.name)],
    color: whiskey }, { tag: [tags.definition(tags.name), tags.separator],
    color: ivory }, { tag: [tags.typeName, tags.className, tags.number, tags.changed, tags.annotation, tags.modifier, tags.self, tags.namespace],
    color: chalky }, { tag: [tags.operator, tags.operatorKeyword, tags.url, tags.escape, tags.regexp, tags.link, tags.special(tags.string)],
    color: cyan }, { tag: [tags.meta, tags.comment],
    color: stone }, { tag: tags.strong,
    fontWeight: "bold" }, { tag: tags.emphasis,
    fontStyle: "italic" }, { tag: tags.link,
    color: stone,
    textDecoration: "underline" }, { tag: tags.heading,
    fontWeight: "bold",
    color: coral }, { tag: [tags.atom, tags.bool, tags.special(tags.variableName)],
    color: whiskey }, { tag: [tags.processingInstruction, tags.string, tags.inserted],
    color: sage }, { tag: tags.invalid,
    color: invalid });
/// Extension to enable the One Dark theme (both the editor theme and
/// the highlight style).
const oneDark = [oneDarkTheme, oneDarkHighlightStyle];

export { oneDark, oneDarkHighlightStyle, oneDarkTheme };
